# gydo.py

A Python Library for interacting with Discord's API

## Table of Contents

- [Example](#example)
- [Others](#others)
- [Contributing](#contributing)

## Example

```py
import gydo

client = gydo.Client("TOKEN")
```

For now, It only logs the Information of your bot, and logs it in. After gydo.py Logs in to your bot, you should see your bot online. It also should log/print something to your console if someone chats to a server, and your bot is in it.

## Others

`gydo.py` is currently on it's beta stages, so expect it to have some bugs, or if something is incomplete.

Report bugs on our [Github Repository](https://github.com/Gydo-Team/gydo.py/)

## Contributing

To contribute on gydo.py you can make pull request on our [Github Repository](https://github.com/Gydo-Team/gydo.py/) 

...and Thanks for contributing!